;; Generated package description from inspector.el  -*- no-byte-compile: t -*-
(define-package "inspector" "0.30.0.20230505.172927" "Tool for inspection of Emacs Lisp objects" '((emacs "27.1")) :commit "01fcdc28a1f66df5bfc7f10e48923056af5234a5" :authors '(("Mariano Montone" . "marianomontone@gmail.com")) :maintainer '("Mariano Montone" . "marianomontone@gmail.com") :keywords '("debugging" "tool" "lisp" "development") :url "https://github.com/mmontone/emacs-inspector")
